Changelog
=========

1.1.7
-----
 - updated packaging

1.1.6
-----
 - remove targets list from dispatched messages
 - added support for Python 3.10 and 3.11

1.1.5
-----
 - merge avec origin/master

1.1.4
-----
 - added configuration option to disable SSL certificates verification
 - updated logging

1.1.3
-----
 - updated package dependencies

1.1.2
-----
 - updated package dependencies

1.1.1
-----
 - updated package dependencies

1.1.0
-----
 - added HTTP monitoring endpoint
 - added Elastic-APM support
 - added configuration file example

1.0.0
-----
 - initial release
